@@ -44,6 +44,6 @@ handle callerName tag (Options includeDead) = do
 
     let command = circleCommand callerName includeDead
 
-    case runExcept (execWriterT $ execStateT (apply command) game) of
+    case runExcept . execWriterT $ execStateT (apply command) game of
         Left errorMessages  -> exitWith failure { messages = errorMessages }
         Right messages      -> exitWith success { messages = messages }
