@@ -14,22 +14,21 @@ module Werewolf.Command.Pass (
     handle,
 ) where
 
-import Control.Lens
 import Control.Monad.Except
 import Control.Monad.Extra
+import Control.Monad.Random
 import Control.Monad.State
 import Control.Monad.Writer
 
 import Data.Text (Text)
 
 import Game.Werewolf
-import Game.Werewolf.Command.DevotedServant as DevotedServant
-import Game.Werewolf.Command.Witch          as Witch
+import Game.Werewolf.Command.Witch
 
 import Werewolf.Game
 import Werewolf.Messages
 
-handle :: MonadIO m => Text -> Text -> m ()
+handle :: (MonadIO m, MonadRandom m) => Text -> Text -> m ()
 handle callerName tag = do
     unlessM (doesGameExist tag) $ exitWith failure
         { messages = [noGameRunningMessage callerName]
@@ -37,13 +36,9 @@ handle callerName tag = do
 
     game <- readGame tag
 
-    command <- case game ^. stage of
-            DevotedServantsTurn -> return $ DevotedServant.passCommand callerName
-            WitchsTurn          -> return $ Witch.passCommand callerName
-            _                   -> exitWith failure
-                { messages = [playerCannotDoThatRightNowMessage callerName]
-                }
+    let command = passCommand callerName
 
-    case runExcept (runWriterT $ execStateT (apply command >> checkStage >> checkGameOver) game) of
+    result <- runExceptT . runWriterT $ execStateT (apply command >> checkStage >> checkGameOver) game
+    case result of
         Left errorMessages      -> exitWith failure { messages = errorMessages }
         Right (game', messages) -> writeOrDeleteGame tag game' >> exitWith success { messages = messages }
