@@ -40,15 +40,18 @@ module Game.Werewolf.Messages (
     -- * Status messages
     currentStageMessages, rolesInGameMessage, playersInGameMessage, waitingOnMessage,
 
-    -- * Angel's turn messages
-    angelJoinedVillagersMessage,
-
-    -- * Devoted Servant's turn messages
-    devotedServantRevealedMessage, devotedServantJoinedPackMessages,
-
     -- * Druid's turn messages
     ferinaGruntsMessage,
 
+    -- * Fallen Angel's turn messages
+    fallenAngelJoinedVillagersMessage,
+
+    -- * Hunter's turn messages
+    playerShotMessage,
+
+    -- * Orphan's turn messages
+    orphanJoinedPackMessages,
+
     -- * Protector's turn messages
 
     -- ** Error messages
@@ -63,6 +66,9 @@ module Game.Werewolf.Messages (
     -- * Seer's turn messages
     playerSeenMessage,
 
+    -- * Village Drunk's turn messages
+    villageDrunkJoinedVillageMessage, villageDrunkJoinedPackMessages,
+
     -- * Villages' turn messages
     playerMadeLynchVoteMessage, playerLynchedMessage, noPlayerLynchedMessage,
     jesterLynchedMessage, scapegoatLynchedMessage,
@@ -76,9 +82,6 @@ module Game.Werewolf.Messages (
     -- ** Error messages
     playerCannotDevourAnotherWerewolfMessage,
 
-    -- * Wild-child's turn messages
-    wildChildJoinedPackMessages,
-
     -- ** Error messages
     playerCannotChooseSelfMessage,
 
@@ -87,19 +90,16 @@ module Game.Werewolf.Messages (
 
     -- ** Error messages
     playerHasAlreadyHealedMessage, playerHasAlreadyPoisonedMessage,
-
-    -- * Wolf-hound's turn messages
-
-    -- ** Error messages
-    allegianceDoesNotExistMessage,
 ) where
 
 import Control.Arrow
 import Control.Lens
+import Control.Lens.Extra
 
 import           Data.List.Extra
-import           Data.Text       (Text)
-import qualified Data.Text       as T
+import           Data.String.Humanise
+import           Data.Text            (Text)
+import qualified Data.Text            as T
 
 import           Game.Werewolf.Game
 import           Game.Werewolf.Player
@@ -112,20 +112,22 @@ newGameMessages game = concat
     [ [newPlayersInGameMessage $ players' ^.. names]
     , [rolesInGameMessage Nothing $ players' ^.. roles]
     , map newPlayerMessage players'
-    , villagerVillagerMessages
+    , beholderMessages
+    , trueVillagerMessages
     , stageMessages game
     ]
     where
-        players'                    = game ^. players
-        villagerVillagerMessages    = case players' ^? villagerVillagers of
-            Just villagerVillager   -> [villagerVillagerMessage $ villagerVillager ^. name]
+        players'                = game ^. players
+        beholderMessages        = case (,) <$> players' ^? beholders <*> players' ^? seers of
+            Just (beholder, seer)   -> [beholderMessage (beholder ^. name) (seer ^. name)]
             _                       -> []
+        trueVillagerMessages    = case players' ^? trueVillagers of
+            Just trueVillager   -> [trueVillagerMessage $ trueVillager ^. name]
+            _                   -> []
 
 newPlayersInGameMessage :: [Text] -> Message
 newPlayersInGameMessage playerNames = publicMessage $ T.concat
-    [ "A new game of werewolf is starting with "
-    , concatList playerNames, "!"
-    ]
+    ["A new game of werewolf is starting with ", concatList playerNames, "!"]
 
 newPlayerMessage :: Player -> Message
 newPlayerMessage player = privateMessage (player ^. name) $ T.intercalate "\n"
@@ -136,52 +138,59 @@ newPlayerMessage player = privateMessage (player ^. name) $ T.intercalate "\n"
     where
         playerRole = player ^. role
 
-villagerVillagerMessage :: Text -> Message
-villagerVillagerMessage name = publicMessage $ T.unwords
-    [ "Unguarded advice is seldom given, for advice is a dangerous gift,"
-    , "even from the wise to the wise, and all courses may run ill."
-    , "Yet as you feel like you need help, I begrudgingly leave you with this:"
-    , name, "is the Villager-Villager."
+beholderMessage :: Text -> Text -> Message
+beholderMessage to seerName = privateMessage to $ T.concat
+    [ "The Seer has always been held in high regard among the Villagers. Few are as lucky as you to"
+    , " know the Seer, ", seerName, ", personally."
+    ]
+
+trueVillagerMessage :: Text -> Message
+trueVillagerMessage name = publicMessage $ T.unwords
+    [ "Unguarded advice is seldom given, for advice is a dangerous gift, even from the wise to the"
+    , "wise, and all courses may run ill. Yet as you feel like you need help, I begrudgingly leave"
+    , "you with this:", name, "is the True Villager."
     ]
 
 stageMessages :: Game -> [Message]
 stageMessages game = case game ^. stage of
-    DevotedServantsTurn -> devotedServantsTurnMessages devotedServantsName victimsName
     FerinasGrunt        -> []
     GameOver            -> []
+    HuntersTurn1        -> huntersTurnMessages huntersName
+    HuntersTurn2        -> huntersTurnMessages huntersName
     Lynching            -> []
+    OrphansTurn         -> orphansTurnMessages orphansName
     ProtectorsTurn      -> protectorsTurnMessages protectorsName
     ScapegoatsTurn      -> scapegoatsTurnMessages scapegoatsName
     SeersTurn           -> seersTurnMessages seersName
     Sunrise             -> [sunriseMessage]
     Sunset              -> [nightFallsMessage]
+    VillageDrunksTurn   -> [villageDrunksTurnMessage]
     VillagesTurn        -> if isFirstRound game
         then firstVillagesTurnMessages
         else villagesTurnMessages
     WerewolvesTurn      -> if isFirstRound game
         then firstWerewolvesTurnMessages aliveWerewolfNames
         else werewolvesTurnMessages aliveWerewolfNames
-    WildChildsTurn      -> wildChildsTurnMessages wildChildsName
     WitchsTurn          -> witchsTurnMessages game
-    WolfHoundsTurn      -> wolfHoundsTurnMessages wolfHoundsName
     where
         players'            = game ^. players
+        huntersName         = players' ^?! hunters . name
+        orphansName         = players' ^?! orphans . name
         protectorsName      = players' ^?! protectors . name
-        devotedServantsName = players' ^?! devotedServants . name
-        victimsName         = head (getVoteResult game) ^. name
         scapegoatsName      = players' ^?! scapegoats . name
         seersName           = players' ^?! seers . name
         aliveWerewolfNames  = players' ^.. werewolves . alive . name
-        wildChildsName      = players' ^?! wildChildren . name
-        wolfHoundsName      = players' ^?! wolfHounds . name
 
-devotedServantsTurnMessages :: Text -> Text -> [Message]
-devotedServantsTurnMessages to victimsName =
-    [ publicMessage "The Devoted Servant ponders."
-    , privateMessage to $ T.concat
-        [ "Would you like to `reveal` yourself and take on ", victimsName, "'s role?"
-        , " (Or you can type `pass`.)"
-        ]
+huntersTurnMessages :: Text -> [Message]
+huntersTurnMessages huntersName =
+    [ publicMessage $ T.unwords ["Just before", huntersName, "was murdered they let off a shot."]
+    , privateMessage huntersName "Whom do you `choose` to kill with your last shot?"
+    ]
+
+orphansTurnMessages :: Text -> [Message]
+orphansTurnMessages to =
+    [ publicMessage "The Orphan wakes up."
+    , privateMessage to "Whom do you `choose` to be your role model?"
     ]
 
 protectorsTurnMessages :: Text -> [Message]
@@ -192,7 +201,7 @@ protectorsTurnMessages to =
 
 scapegoatsTurnMessages :: Text -> [Message]
 scapegoatsTurnMessages scapegoatsName =
-    [ publicMessage "Just before he burns to a complete crisp, he cries out a dying wish."
+    [ publicMessage "Just before the Scapegoat burns to a complete crisp, they cry out a dying wish."
     , publicMessage $ T.concat [scapegoatsName, ", whom do you `choose` to vote on the next day?"]
     ]
 
@@ -202,6 +211,9 @@ seersTurnMessages to =
     , privateMessage to "Whose allegiance would you like to `see`?"
     ]
 
+villageDrunksTurnMessage :: Message
+villageDrunksTurnMessage = publicMessage "The Village Drunk sobers up."
+
 sunriseMessage :: Message
 sunriseMessage = publicMessage "The sun rises. Everybody wakes up and opens their eyes..."
 
@@ -209,17 +221,17 @@ nightFallsMessage :: Message
 nightFallsMessage = publicMessage "Night falls, the village is asleep."
 
 firstVillagesTurnMessages :: [Message]
-firstVillagesTurnMessages = angelInPlayMessage : villagesTurnMessages
+firstVillagesTurnMessages = fallenAngelInPlayMessage : villagesTurnMessages
     where
-        angelInPlayMessage = publicMessage $ T.unwords
-            [ "Alas, again I regrettably yield advice: an angelic menace walks among you."
-            , "Do not cast your votes lightly,"
-            , "for he will relish in this opportunity to be free from his terrible nightmare."
+        fallenAngelInPlayMessage = publicMessage $ T.unwords
+            [ "Alas, again I regrettably yield advice: an angelic menace walks among you. Do not"
+            , "cast your votes lightly, for they will relish in this opportunity to be free from"
+            , "their terrible nightmare."
             ]
 
 villagesTurnMessages :: [Message]
 villagesTurnMessages =
-    [ publicMessage "As the village gathers in the square the town clerk calls for a vote."
+    [ publicMessage "As the village gathers in the square the Town Clerk calls for a vote."
     , publicMessage "Whom would you like to `vote` to lynch?"
     ]
 
@@ -229,9 +241,8 @@ firstWerewolvesTurnMessages tos =
     ++ werewolvesTurnMessages tos
     where
         packMessage werewolfName    = T.unwords
-            [ "You feel restless, like an old curse is keeping you from sleep."
-            , "It seems you're not the only one..."
-            , packNames werewolfName
+            [ "You feel restless, like an old curse is keeping you from sleep. It seems you're not"
+            , "the only one...", packNames werewolfName
             , conjugateToBe (length tos - 1), "also emerging from their"
             , tryPlural (length tos - 1) "home"
             ]
@@ -242,12 +253,6 @@ werewolvesTurnMessages tos =
     publicMessage "The Werewolves wake up, transform and choose a new victim."
     : groupMessages tos "Whom would you like to `vote` to devour?"
 
-wildChildsTurnMessages :: Text -> [Message]
-wildChildsTurnMessages to =
-    [ publicMessage "The Wild-child wakes up."
-    , privateMessage to "Whom do you `choose` to be your role model?"
-    ]
-
 witchsTurnMessages :: Game -> [Message]
 witchsTurnMessages game = concat
     [ [wakeUpMessage]
@@ -274,30 +279,23 @@ witchsTurnMessages game = concat
             | game ^. poisonUsed    = []
             | otherwise             = [privateMessage witchsName "Would you like to `poison` anyone?"]
 
-wolfHoundsTurnMessages :: Text -> [Message]
-wolfHoundsTurnMessages to =
-    [ publicMessage "The Wolf-hound wakes up."
-    , privateMessage to
-        "Which allegiance do you `choose` to be aligned with? (Either `villagers` or `werewolves`.)"
-    ]
-
 gameOverMessages :: Game -> [Message]
 gameOverMessages game
-    | hasAngelWon game      = concat
-        [ [publicMessage "You should have heeded my warning, for now the Angel has been set free!"]
-        , [publicMessage "The game is over! The Angel has won."]
+    | hasFallenAngelWon game    = concat
+        [ [publicMessage "You should have heeded my warning, for now the Fallen Angel has been set free!"]
+        , [publicMessage "The game is over! The Fallen Angel has won."]
         , [playerRolesMessage]
-        , playerWonMessages
-        , playerLostMessages
+        , [playerWonMessage fallenAngelsName]
+        , map playerLostMessage (game ^.. players . names \\ [fallenAngelsName])
         ]
-    | hasVillagersWon game  = concat
+    | hasVillagersWon game      = concat
         [ [publicMessage "The game is over! The Villagers have won."]
         , [playerRolesMessage]
         , playerWonMessages
         , playerContributedMessages
         , playerLostMessages
         ]
-    | hasWerewolvesWon game = concat
+    | hasWerewolvesWon game     = concat
         [ [publicMessage "The game is over! The Werewolves have won."]
         , [playerRolesMessage]
         , playerWonMessages
@@ -315,10 +313,9 @@ gameOverMessages game
             ]
 
         winningAllegiance
-            | hasAngelWon game      = Angel
-            | hasVillagersWon game  = Villagers
-            | hasWerewolvesWon game = Werewolves
-            | otherwise             = undefined
+            | hasVillagersWon game      = Villagers
+            | hasWerewolvesWon game     = Werewolves
+            | otherwise                 = undefined
 
         winningPlayers  = game ^.. players . traverse . filteredBy (role . allegiance) winningAllegiance
         losingPlayers   = game ^. players \\ winningPlayers
@@ -327,6 +324,8 @@ gameOverMessages game
         playerContributedMessages   = map playerContributedMessage (winningPlayers ^.. traverse . dead . name)
         playerLostMessages          = map playerLostMessage (losingPlayers ^.. names)
 
+        fallenAngelsName = game ^?! players . fallenAngels . name
+
 playerWonMessage :: Text -> Message
 playerWonMessage to = privateMessage to "Victory! You won!"
 
@@ -398,24 +397,8 @@ currentStageMessages _ Lynching     = []
 currentStageMessages _ Sunrise      = []
 currentStageMessages _ Sunset       = []
 currentStageMessages to turn        = [privateMessage to $ T.concat
-    [ "It's currently the ", showTurn turn, " turn."
+    [ "It's currently the ", humanise turn, "."
     ]]
-    where
-        showTurn :: Stage -> Text
-        showTurn DevotedServantsTurn    = "Devoted Servant's"
-        showTurn FerinasGrunt           = undefined
-        showTurn GameOver               = undefined
-        showTurn Lynching               = undefined
-        showTurn ProtectorsTurn         = "Protector's"
-        showTurn ScapegoatsTurn         = "Scapegoat's"
-        showTurn SeersTurn              = "Seer's"
-        showTurn Sunrise                = undefined
-        showTurn Sunset                 = undefined
-        showTurn VillagesTurn           = "village's"
-        showTurn WerewolvesTurn         = "Werewolves'"
-        showTurn WildChildsTurn         = "Wild-child's"
-        showTurn WitchsTurn             = "Witch's"
-        showTurn WolfHoundsTurn         = "Wolf-hound's"
 
 rolesInGameMessage :: Maybe Text -> [Role] -> Message
 rolesInGameMessage mTo roles = Message mTo $ T.concat
@@ -438,7 +421,7 @@ playersInGameMessage to players = privateMessage to . T.intercalate "\n" $
 
         alivePlayersText            = T.concat
             [ "The following players are still alive: "
-            , concatList $ map (\player -> if is villagerVillager player then playerNameWithRole player else player ^. name) alivePlayers, "."
+            , concatList $ map (\player -> if is trueVillager player then playerNameWithRole player else player ^. name) alivePlayers, "."
             ]
         deadPlayersText             = T.concat
             [ "The following players are dead: "
@@ -450,53 +433,47 @@ waitingOnMessage :: Maybe Text -> [Text] -> Message
 waitingOnMessage mTo playerNames = Message mTo $ T.concat
     ["Waiting on ", concatList playerNames, "..."]
 
-angelJoinedVillagersMessage :: Message
-angelJoinedVillagersMessage = publicMessage $ T.unwords
-    [ "You hear the Angel wrought with anger off in the distance."
-    , "He failed to attract the discriminatory vote of the village"
-    , "or the devouring vindictiveness of the lycanthropes."
-    , "Now he is stuck here, doomed forever to live out a mortal life as a Villager."
-    ]
-
-devotedServantRevealedMessage :: Text -> Message
-devotedServantRevealedMessage devotedServantsName = publicMessage $ T.unwords
-    [ devotedServantsName, "stands up in horror."
-    , "Determined to not let their master's abilities be lost forever,"
-    , "she selflessly takes on their role."
-    ]
-
-devotedServantJoinedPackMessages :: Text -> [Text] -> [Message]
-devotedServantJoinedPackMessages devotedServantsName werewolfNames =
-    privateMessage devotedServantsName (T.unwords $ masterWasWerewolfMessage:packMessages)
-    : groupMessages werewolfNames (T.unwords
-        [ devotedServantsName, "heads towards the woods in search of his master's home and family."
-        ])
-    where
-        masterWasWerewolfMessage = T.unwords
-            [ "Upon learning your master was a Werewolf,"
-            , "you head towards the woods to learn more about his home and family."
-            ]
-        packMessages
-            | null werewolfNames    = []
-            | otherwise             =
-                [ T.unwords
-                    ["As you enter you see his pack", concatList werewolfNames , "waiting for you."]
-                ]
-
 ferinaGruntsMessage :: Message
-ferinaGruntsMessage = publicMessage $ T.unwords
-    [ "Ferina wakes from her slumber, disturbed and on edge."
-    , "She loudly grunts as she smells danger."
+ferinaGruntsMessage = publicMessage
+    "Ferina wakes from her slumber, disturbed and on edge. She loudly grunts as she smells danger."
+
+fallenAngelJoinedVillagersMessage :: Message
+fallenAngelJoinedVillagersMessage = publicMessage $ T.unwords
+    [ "You hear the Fallen Angel wrought with anger off in the distance. They failed to attract the"
+    , "prejudiced vote of the village to leave this world. Now they are stuck here, doomed forever"
+    , "to live out a mortal life as a Villager."
     ]
 
+playerShotMessage :: Player -> Message
+playerShotMessage target = publicMessage $ T.unwords
+    [ targetName, "the", targetRole, "slumps down to the ground, hands clutching at their chest"
+    , "while blood slips between their fingers and pools around them."
+    ]
+    where
+        targetName = target ^. name
+        targetRole = target ^. role . Role.name
+
+orphanJoinedPackMessages :: Text -> [Text] -> [Message]
+orphanJoinedPackMessages orphansName werewolfNames =
+    privateMessage orphansName (T.unwords
+        [ "The death of your role model is distressing. Without second thought you abandon the"
+        , "Villagers and run off into the woods, towards a new home. As you arrive you see the"
+        , tryPlural (length werewolfNames) "face", "of"
+        , concatList werewolfNames, "waiting for you."
+        ])
+    : groupMessages werewolfNames (T.unwords
+        [ orphansName, "the Orphan scampers off into the woods. Without their role model they have"
+        , "abandoned the village and are in search of a new home. You welcome them into your pack."
+        ])
+
 playerCannotProtectSamePlayerTwiceInARowMessage :: Text -> Message
 playerCannotProtectSamePlayerTwiceInARowMessage to =
     privateMessage to "You cannot protect the same player twice in a row!"
 
 scapegoatChoseAllowedVotersMessage :: [Text] -> Message
 scapegoatChoseAllowedVotersMessage allowedVoters = publicMessage $ T.unwords
-    [ "On the next day only", concatList allowedVoters, "shall be allowed to vote."
-    , "The town crier, realising how foolish it was to kill him, grants him this wish."
+    [ "On the next day only", concatList allowedVoters, "shall be allowed to vote. The Town Crier,"
+    , "realising how foolish it was to kill the Scapegoat, grants them this wish."
     ]
 
 playerMustChooseAtLeastOneTargetMessage :: Text -> Message
@@ -509,30 +486,51 @@ playerCannotChooseJesterMessage to =
 
 playerSeenMessage :: Text -> Player -> Message
 playerSeenMessage to target = privateMessage to $ T.concat
-    [ targetName, " is aligned with the ", T.pack $ show allegiance', "."
-    ]
+    [targetName, " is aligned with ", article, humanise allegiance', "."]
     where
         targetName  = target ^. name
-        allegiance' = target ^. role . allegiance
+        allegiance'
+            | is alphaWolf target   = Villagers
+            | is lycan target       = Werewolves
+            | otherwise             = target ^. role . allegiance
+        article     = if allegiance' == NoOne then "" else "the "
 
-playerMadeLynchVoteMessage :: Text -> Text -> Message
-playerMadeLynchVoteMessage voterName targetName = publicMessage $ T.concat
+villageDrunkJoinedVillageMessage :: Text -> Message
+villageDrunkJoinedVillageMessage to = privateMessage to $ T.unwords
+    [ "Somehow you managed to avoid getting killed while in your drunken stupor. Thank God for"
+    , "that, maybe now you can actually help the village."
+    ]
+
+villageDrunkJoinedPackMessages :: Text -> [Text] -> [Message]
+villageDrunkJoinedPackMessages villageDrunksName werewolfNames =
+    privateMessage villageDrunksName (T.concat
+        [ "As you start to feel sober for the first time in days a new thirst begins to take hold."
+        , " The bloodthirst starts to bring back memories, memories of your true home with "
+        , concatList werewolfNames, "."
+        ])
+    : groupMessages werewolfNames (T.unwords
+        [ villageDrunksName
+        , "the Village Drunk has finally sobered up and remembered their true home."
+        ])
+
+playerMadeLynchVoteMessage :: Maybe Text -> Text -> Text -> Message
+playerMadeLynchVoteMessage mTo voterName targetName = Message mTo $ T.concat
     [ voterName, " voted to lynch ", targetName, "."
     ]
 
 playerLynchedMessage :: Player -> Message
 playerLynchedMessage player
-    | is simpleWerewolf player  = publicMessage $ T.concat
-        [ playerName, " is tied up to a pyre and set alight."
-        , " As they scream their body starts to contort and writhe, transforming into "
-        , article playerRole, " ", playerRole ^. Role.name, "."
-        , " Thankfully they go limp before breaking free of their restraints."
+    | is simpleWerewolf player
+        || is alphaWolf player  = publicMessage $ T.concat
+        [ playerName, " is tied up to a pyre and set alight. As they scream their body starts to "
+        , "contort and writhe, transforming into ", article playerRole, " "
+        , playerRole ^. Role.name, ".", " Thankfully they go limp before breaking free of their "
+        , "restraints."
         ]
     | otherwise                 = publicMessage $ T.concat
-        [ playerName, " is tied up to a pyre and set alight."
-        , " Eventually the screams start to die and with their last breath,"
-        , " they reveal themselves as "
-        , article playerRole, " ", playerRole ^. Role.name, "."
+        [ playerName, " is tied up to a pyre and set alight. Eventually the screams start to die "
+        , "and with their last breath, they reveal themselves as ", article playerRole, " "
+        , playerRole ^. Role.name, "."
         ]
     where
         playerName = player ^. name
@@ -540,8 +538,8 @@ playerLynchedMessage player
 
 noPlayerLynchedMessage :: Message
 noPlayerLynchedMessage = publicMessage $ T.unwords
-    [ "Daylight is wasted as the townsfolk squabble over whom to tie up."
-    , "Looks like no-one is being burned this day."
+    [ "Daylight is wasted as the townsfolk squabble over whom to tie up. Looks like no-one is being"
+    , "burned this day."
     ]
 
 jesterLynchedMessage :: Text -> Message
@@ -586,20 +584,6 @@ noPlayerDevouredMessage = publicMessage $ T.unwords
 playerCannotDevourAnotherWerewolfMessage :: Text -> Message
 playerCannotDevourAnotherWerewolfMessage to = privateMessage to "You cannot devour another Werewolf!"
 
-wildChildJoinedPackMessages :: Text -> [Text] -> [Message]
-wildChildJoinedPackMessages wildChildsName werewolfNames =
-    privateMessage wildChildsName (T.unwords
-        [ "The death of your role model is distressing."
-        , "Without second thought you abandon the Villagers and run off into the woods,"
-        , "towards your old home."
-        , "As you arrive you see the familiar", tryPlural (length werewolfNames) "face", "of"
-        , concatList werewolfNames, "waiting and happy to have you back."
-        ])
-    : groupMessages werewolfNames (T.unwords
-        [ wildChildsName, "the Wild-child scampers off into the woods."
-        , "Without his role model nothing is holding back his true, wolfish, nature."
-        ])
-
 playerCannotChooseSelfMessage :: Text -> Message
 playerCannotChooseSelfMessage to = privateMessage to "You cannot choose yourself!"
 
@@ -618,11 +602,6 @@ playerHasAlreadyHealedMessage to = privateMessage to "You've already healed some
 playerHasAlreadyPoisonedMessage :: Text -> Message
 playerHasAlreadyPoisonedMessage to = privateMessage to "You've already poisoned someone!"
 
-allegianceDoesNotExistMessage :: Text -> Text -> Message
-allegianceDoesNotExistMessage to name = privateMessage to $ T.unwords
-    [ "Allegiance", name, "does not exist."
-    ]
-
 article :: Role -> Text
 article role
     | role `elem` restrictedRoles   = "the"
