@@ -11,18 +11,13 @@ module Game.Werewolf.Test.Arbitrary (
     -- * Initial arbitraries
 
     -- ** Game
-    NewGame(..),
-    GameAtDevotedServantsTurn(..), GameAtGameOver(..), GameAtProtectorsTurn(..),
+    GameAtGameOver(..), GameAtHuntersTurn(..), GameAtOrphansTurn(..), GameAtProtectorsTurn(..),
     GameAtScapegoatsTurn(..), GameAtSeersTurn(..), GameAtSunrise(..), GameAtVillagesTurn(..),
-    GameAtWerewolvesTurn(..), GameAtWildChildsTurn(..), GameAtWitchsTurn(..),
-    GameAtWolfHoundsTurn(..),
-    GameOnSecondRound(..),
-    GameWithAllegianceChosen(..), GameWithAllowedVoters(..), GameWithConflictingVote(..),
-    GameWithDeadPlayers(..), GameWithDevourEvent(..), GameWithDevourVotes(..), GameWithHeal(..),
+    GameAtWerewolvesTurn(..), GameAtWitchsTurn(..),
+
+    GameWithAllowedVoters(..), GameWithDevourEvent(..), GameWithDevourVotes(..), GameWithHeal(..),
     GameWithJesterRevealedAtVillagesTurn(..), GameWithLynchVotes(..), GameWithMajorityVote(..),
-    GameWithOneAllegianceAlive(..), GameWithPassAtDevotedServantsTurn(..), GameWithPoison(..),
-    GameWithProtect(..), GameWithProtectAndDevourVotes(..), GameWithRoleModel(..),
-    GameWithRoleModelAtVillagesTurn(..), GameWithSee(..),
+    GameWithPoison(..), GameWithProtect(..),
 
     -- ** Player
     arbitraryPlayerSet,
@@ -30,18 +25,19 @@ module Game.Werewolf.Test.Arbitrary (
     -- * Contextual arbitraries
 
     -- ** Command
-    arbitraryCommand, arbitraryWolfHoundChooseCommand, arbitraryWildChildChooseCommand,
-    arbitraryScapegoatChooseCommand, arbitraryHealCommand, arbitraryDevotedServantPassCommand,
-    arbitraryWitchPassCommand, arbitraryPoisonCommand, arbitraryProtectCommand,
-    arbitraryQuitCommand, arbitraryRevealCommand, arbitrarySeeCommand, arbitraryWerewolfVoteCommand,
-    arbitraryVillagerVoteCommand,
+    arbitraryCommand, arbitraryHunterChooseCommand, arbitraryOrphanChooseCommand,
+    arbitraryScapegoatChooseCommand, arbitraryHealCommand, arbitraryPassCommand,
+    arbitraryPoisonCommand, arbitraryProtectCommand, arbitraryQuitCommand, arbitrarySeeCommand,
+    arbitraryWerewolfVoteCommand, arbitraryVillagerVoteCommand,
+
     runArbitraryCommands,
 
     -- ** Player
     arbitraryPlayer, arbitraryWerewolf,
 ) where
 
-import Control.Lens hiding (elements, isn't)
+import Control.Lens       hiding (elements, isn't)
+import Control.Lens.Extra
 
 import           Data.List.Extra
 import           Data.Maybe
@@ -49,16 +45,15 @@ import           Data.Text       (Text)
 import qualified Data.Text       as T
 
 import Game.Werewolf
-import Game.Werewolf.Command.DevotedServant as DevotedServant
 import Game.Werewolf.Command.Global
+import Game.Werewolf.Command.Hunter    as Hunter
+import Game.Werewolf.Command.Orphan    as Orphan
 import Game.Werewolf.Command.Protector
-import Game.Werewolf.Command.Scapegoat      as Scapegoat
+import Game.Werewolf.Command.Scapegoat as Scapegoat
 import Game.Werewolf.Command.Seer
-import Game.Werewolf.Command.Villager       as Villager
-import Game.Werewolf.Command.Werewolf       as Werewolf
-import Game.Werewolf.Command.WildChild      as WildChild
-import Game.Werewolf.Command.Witch          as Witch
-import Game.Werewolf.Command.WolfHound      as WolfHound
+import Game.Werewolf.Command.Villager  as Villager
+import Game.Werewolf.Command.Werewolf  as Werewolf
+import Game.Werewolf.Command.Witch
 import Game.Werewolf.Test.Util
 
 import Prelude hiding (round)
@@ -67,8 +62,8 @@ import Test.QuickCheck
 
 instance Arbitrary Game where
     arbitrary = do
-        (NewGame game)  <- arbitrary
-        stage'          <- arbitrary
+        game    <- newGame <$> arbitraryPlayerSet
+        stage'  <- arbitrary
 
         return $ game & stage .~ stage'
 
@@ -90,22 +85,6 @@ instance Arbitrary Allegiance where
 instance Arbitrary Text where
     arbitrary = T.pack <$> vectorOf 6 (elements ['a'..'z'])
 
-newtype NewGame = NewGame Game
-    deriving (Eq, Show)
-
-instance Arbitrary NewGame where
-    arbitrary = NewGame . newGame <$> arbitraryPlayerSet
-
-newtype GameAtDevotedServantsTurn = GameAtDevotedServantsTurn Game
-    deriving (Eq, Show)
-
-instance Arbitrary GameAtDevotedServantsTurn where
-    arbitrary = do
-        (GameWithMajorityVote game) <- suchThat arbitrary $ \(GameWithMajorityVote game) ->
-            isn't devotedServant (head $ getVoteResult game)
-
-        return $ GameAtDevotedServantsTurn (run_ checkStage game)
-
 newtype GameAtGameOver = GameAtGameOver Game
     deriving (Eq, Show)
 
@@ -115,6 +94,25 @@ instance Arbitrary GameAtGameOver where
 
         return $ GameAtGameOver (game & stage .~ GameOver)
 
+newtype GameAtHuntersTurn = GameAtHuntersTurn Game
+    deriving (Eq, Show)
+
+instance Arbitrary GameAtHuntersTurn where
+    arbitrary = do
+        game <- arbitrary
+        turn <- elements [HuntersTurn1, HuntersTurn2]
+
+        return $ GameAtHuntersTurn (game & stage .~ turn)
+
+newtype GameAtOrphansTurn = GameAtOrphansTurn Game
+    deriving (Eq, Show)
+
+instance Arbitrary GameAtOrphansTurn where
+    arbitrary = do
+        game <- arbitrary
+
+        return $ GameAtOrphansTurn (game & stage .~ OrphansTurn)
+
 newtype GameAtProtectorsTurn = GameAtProtectorsTurn Game
     deriving (Eq, Show)
 
@@ -169,15 +167,6 @@ instance Arbitrary GameAtWerewolvesTurn where
 
         return $ GameAtWerewolvesTurn (game & stage .~ WerewolvesTurn)
 
-newtype GameAtWildChildsTurn = GameAtWildChildsTurn Game
-    deriving (Eq, Show)
-
-instance Arbitrary GameAtWildChildsTurn where
-    arbitrary = do
-        game <- arbitrary
-
-        return $ GameAtWildChildsTurn (game & stage .~ WildChildsTurn)
-
 newtype GameAtWitchsTurn = GameAtWitchsTurn Game
     deriving (Eq, Show)
 
@@ -187,34 +176,6 @@ instance Arbitrary GameAtWitchsTurn where
 
         return $ GameAtWitchsTurn (game & stage .~ WitchsTurn)
 
-newtype GameAtWolfHoundsTurn = GameAtWolfHoundsTurn Game
-    deriving (Eq, Show)
-
-instance Arbitrary GameAtWolfHoundsTurn where
-    arbitrary = do
-        game <- arbitrary
-
-        return $ GameAtWolfHoundsTurn (game & stage .~ WolfHoundsTurn)
-
-newtype GameOnSecondRound = GameOnSecondRound Game
-    deriving (Eq, Show)
-
-instance Arbitrary GameOnSecondRound where
-    arbitrary = do
-        game <- arbitrary
-
-        return $ GameOnSecondRound (game & round .~ 1)
-
-newtype GameWithAllegianceChosen = GameWithAllegianceChosen Game
-    deriving (Eq, Show)
-
-instance Arbitrary GameWithAllegianceChosen where
-    arbitrary = do
-        (GameAtWolfHoundsTurn game) <- arbitrary
-        (Blind command)             <- arbitraryWolfHoundChooseCommand game
-
-        return $ GameWithAllegianceChosen (run_ (apply command) game)
-
 newtype GameWithAllowedVoters = GameWithAllowedVoters Game
     deriving (Eq, Show)
 
@@ -235,17 +196,6 @@ instance Arbitrary GameWithConflictingVote where
 
         return $ GameWithConflictingVote game
 
-newtype GameWithDeadPlayers = GameWithDeadPlayers Game
-    deriving (Eq, Show)
-
-instance Arbitrary GameWithDeadPlayers where
-    arbitrary = do
-        game                <- arbitrary
-        (NonEmpty players') <- NonEmpty <$> sublistOf (game ^. players)
-        let game'           = foldr killPlayer game (players' ^.. names)
-
-        return $ GameWithDeadPlayers (run_ checkStage game')
-
 newtype GameWithDevourEvent = GameWithDevourEvent Game
     deriving (Eq, Show)
 
@@ -314,48 +264,6 @@ instance Arbitrary GameWithMajorityVote where
 
         return $ GameWithMajorityVote game
 
-newtype GameWithMajorityVoteAtDevotedServantsTurn = GameWithMajorityVoteAtDevotedServantsTurn Game
-    deriving (Eq, Show)
-
-instance Arbitrary GameWithMajorityVoteAtDevotedServantsTurn where
-    arbitrary = do
-        (GameWithMajorityVote game) <- arbitrary
-
-        return . GameWithMajorityVoteAtDevotedServantsTurn $ run_ checkStage game
-
-newtype GameWithOneAllegianceAlive = GameWithOneAllegianceAlive Game
-    deriving (Eq, Show)
-
-instance Arbitrary GameWithOneAllegianceAlive where
-    arbitrary = do
-        game            <- arbitrary
-        allegiance'     <- elements [Villagers, Werewolves]
-        let playerNames = game ^.. players . traverse . filteredBy (role . allegiance) allegiance' . name
-        let game'       = foldr killPlayer game (game ^.. players . names \\ playerNames)
-
-        return $ GameWithOneAllegianceAlive game'
-
-newtype GameWithPassAtDevotedServantsTurn = GameWithPassAtDevotedServantsTurn Game
-    deriving (Eq, Show)
-
-instance Arbitrary GameWithPassAtDevotedServantsTurn where
-    arbitrary = do
-        (GameAtDevotedServantsTurn game)    <- arbitrary
-        (Blind command)                     <- arbitraryDevotedServantPassCommand game
-
-        return $ GameWithPassAtDevotedServantsTurn (run_ (apply command) game)
-
-newtype GameWithPassAtWitchsTurn = GameWithPassAtWitchsTurn Game
-    deriving (Eq, Show)
-
-instance Arbitrary GameWithPassAtWitchsTurn where
-    arbitrary = do
-        game            <- arbitrary
-        let game'       = game & stage .~ WitchsTurn
-        (Blind command) <- arbitraryWitchPassCommand game'
-
-        return $ GameWithPassAtWitchsTurn (run_ (apply command) game')
-
 newtype GameWithPoison = GameWithPoison Game
     deriving (Eq, Show)
 
@@ -378,47 +286,6 @@ instance Arbitrary GameWithProtect where
 
         return $ GameWithProtect (run_ (apply command) game')
 
-newtype GameWithProtectAndDevourVotes = GameWithProtectAndDevourVotes Game
-    deriving (Eq, Show)
-
-instance Arbitrary GameWithProtectAndDevourVotes where
-    arbitrary = do
-        (GameWithProtect game)  <- arbitrary
-        let game'               = run_ checkStage game
-
-        GameWithProtectAndDevourVotes <$> runArbitraryCommands (length $ game' ^. players) game'
-
-newtype GameWithRoleModel = GameWithRoleModel Game
-    deriving (Eq, Show)
-
-instance Arbitrary GameWithRoleModel where
-    arbitrary = do
-        (GameAtWildChildsTurn game) <- arbitrary
-        (Blind command)             <- arbitraryWildChildChooseCommand game
-        let game'                   = run_ (apply command) game
-
-        return $ GameWithRoleModel game'
-
-newtype GameWithRoleModelAtVillagesTurn = GameWithRoleModelAtVillagesTurn Game
-    deriving (Eq, Show)
-
-instance Arbitrary GameWithRoleModelAtVillagesTurn where
-    arbitrary = do
-        (GameWithRoleModel game) <- arbitrary
-
-        return $ GameWithRoleModelAtVillagesTurn (game & stage .~ VillagesTurn)
-
-newtype GameWithSee = GameWithSee Game
-    deriving (Eq, Show)
-
-instance Arbitrary GameWithSee where
-    arbitrary = do
-        game            <- arbitrary
-        let game'       = game & stage .~ SeersTurn
-        (Blind command) <- arbitrarySeeCommand game'
-
-        return $ GameWithSee (run_ (apply command) game')
-
 arbitraryPlayerSet :: Gen [Player]
 arbitraryPlayerSet = do
     n       <- choose (14, 30)
@@ -433,41 +300,39 @@ arbitraryPlayerSet = do
 
 arbitraryCommand :: Game -> Gen (Blind Command)
 arbitraryCommand game = case game ^. stage of
-    DevotedServantsTurn -> oneof
-        [ arbitraryDevotedServantPassCommand game
-        , arbitraryRevealCommand game
-        ]
     FerinasGrunt        -> return $ Blind noopCommand
     GameOver            -> return $ Blind noopCommand
+    HuntersTurn1        -> arbitraryHunterChooseCommand game
+    HuntersTurn2        -> arbitraryHunterChooseCommand game
     Lynching            -> return $ Blind noopCommand
+    OrphansTurn         -> arbitraryOrphanChooseCommand game
     ProtectorsTurn      -> arbitraryProtectCommand game
     ScapegoatsTurn      -> arbitraryScapegoatChooseCommand game
     SeersTurn           -> arbitrarySeeCommand game
     Sunrise             -> return $ Blind noopCommand
     Sunset              -> return $ Blind noopCommand
+    VillageDrunksTurn   -> return $ Blind noopCommand
     VillagesTurn        -> arbitraryVillagerVoteCommand game
     WerewolvesTurn      -> arbitraryWerewolfVoteCommand game
-    WildChildsTurn      -> arbitraryWildChildChooseCommand game
     WitchsTurn          -> oneof
         [ arbitraryHealCommand game
-        , arbitraryWitchPassCommand game
+        , arbitraryPassCommand game
         , arbitraryPoisonCommand game
         ]
-    WolfHoundsTurn      -> arbitraryWolfHoundChooseCommand game
 
-arbitraryWolfHoundChooseCommand :: Game -> Gen (Blind Command)
-arbitraryWolfHoundChooseCommand game = do
-    let wolfHoundsName  = game ^?! players . wolfHounds . name
-    allegianceName      <- elements $ map (T.pack . show) [Villagers, Werewolves]
+arbitraryHunterChooseCommand :: Game -> Gen (Blind Command)
+arbitraryHunterChooseCommand game = do
+    let hunter  = game ^?! players . hunters
+    target      <- arbitraryPlayer game
 
-    return . Blind $ WolfHound.chooseCommand wolfHoundsName allegianceName
+    return . Blind $ Hunter.chooseCommand (hunter ^. name) (target ^. name)
 
-arbitraryWildChildChooseCommand :: Game -> Gen (Blind Command)
-arbitraryWildChildChooseCommand game = do
-    let wildChild   = game ^?! players . wildChildren
-    target          <- suchThat (arbitraryPlayer game) (wildChild /=)
+arbitraryOrphanChooseCommand :: Game -> Gen (Blind Command)
+arbitraryOrphanChooseCommand game = do
+    let orphan  = game ^?! players . orphans
+    target      <- suchThat (arbitraryPlayer game) (orphan /=)
 
-    return . Blind $ WildChild.chooseCommand (wildChild ^. name) (target ^. name)
+    return . Blind $ Orphan.chooseCommand (orphan ^. name) (target ^. name)
 
 arbitraryScapegoatChooseCommand :: Game -> Gen (Blind Command)
 arbitraryScapegoatChooseCommand game = do
@@ -484,17 +349,11 @@ arbitraryHealCommand game = do
         then noopCommand
         else healCommand witchsName
 
-arbitraryDevotedServantPassCommand :: Game -> Gen (Blind Command)
-arbitraryDevotedServantPassCommand game = do
-    let devotedServantsName = game ^?! players . devotedServants . name
-
-    return . Blind $ DevotedServant.passCommand devotedServantsName
-
-arbitraryWitchPassCommand :: Game -> Gen (Blind Command)
-arbitraryWitchPassCommand game = do
+arbitraryPassCommand :: Game -> Gen (Blind Command)
+arbitraryPassCommand game = do
     let witchsName = game ^?! players . witches . name
 
-    return . Blind $ Witch.passCommand witchsName
+    return . Blind $ passCommand witchsName
 
 arbitraryPoisonCommand :: Game -> Gen (Blind Command)
 arbitraryPoisonCommand game = do
@@ -524,12 +383,6 @@ arbitraryQuitCommand game = do
         else elements applicableCallerNames >>= \callersName ->
             return . Blind $ quitCommand callersName
 
-arbitraryRevealCommand :: Game -> Gen (Blind Command)
-arbitraryRevealCommand game = do
-    let devotedServantsName = game ^?! players . devotedServants . name
-
-    return . Blind $ revealCommand devotedServantsName
-
 arbitrarySeeCommand :: Game -> Gen (Blind Command)
 arbitrarySeeCommand game = do
     let seersName   = game ^?! players . seers . name
